@@ -8,7 +8,7 @@ from transformers import BertModel, BertTokenizerFast
 from .model import GlobalPointer
 from .utils import rematch
 
-__all__=['load_NNER']
+__all__=['load_NNER','GlobalPointerNet']
 
 
 class _CustomDataset4test(Dataset):
@@ -56,7 +56,7 @@ class _NamedEntityRecognizer(object):
         self.id2c = id2c
         self.device = device
         self.tokenizer = tokenizer
-        self.model_base = model_base
+        self.model_base = model_base.to(self.device)
 
     def recognize(self, text, threshold=0):
         
@@ -212,6 +212,9 @@ def infer(in_file, out_file='./CMeEE_test_answer.json',
 
 
 if __name__ == '__main__':
+    model_name = 'hfl/chinese-macbert-large'
+    model = GlobalPointerNet(model_name)
+
     in_file = '../CMeEE_test.json'
     #infer(in_file)
 
